BannerAdWidget class

A widget that displays a banner ad.

This widget creates a platform view to display native banner ads.

Example:

BannerAdWidget(
  adUnitId: 'ca-app-pub-xxxxx/xxxxx',
  size: BannerAdSize.adaptive,
  onAdLoaded: () => print('Banner loaded'),
  onAdFailedToLoad: (error) => print('Banner failed: $error'),
)
Inheritance

Constructors

BannerAdWidget({Key? key, required String adUnitId, BannerAdSize size = BannerAdSize.adaptive, AdRequestConfig? requestConfig, VoidCallback? onAdLoaded, dynamic onAdFailedToLoad(String error)?, VoidCallback? onAdClicked, VoidCallback? onAdImpression, String? preloadedBannerId})
const

Properties

adUnitId String
The ad unit ID for the banner ad.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAdClicked VoidCallback?
Called when the ad is clicked.
final
onAdFailedToLoad → dynamic Function(String error)?
Called when the ad fails to load.
final
onAdImpression VoidCallback?
Called when the ad impression is recorded.
final
onAdLoaded VoidCallback?
Called when the ad loads successfully.
final
preloadedBannerId String?
Optional preloaded banner ID returned by loadBannerAd.
final
requestConfig AdRequestConfig?
Optional request configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size BannerAdSize
The size of the banner ad.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BannerAdWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited