NativeAdButtonStyle class

Style configuration for call to action button

Constructors

NativeAdButtonStyle({Color? backgroundColor, Color? textColor, TextStyle? textStyle, EdgeInsets? padding, double? cornerRadius, Border? border})
const
NativeAdButtonStyle.defaultStyle()
factory

Properties

backgroundColor Color?
final
border Border?
final
cornerRadius double?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
final
textStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited