NativeAdMediaAspectRatio enum

Enum for native ad media aspect ratio preferences.

Inheritance
Available extensions

Values

any → const NativeAdMediaAspectRatio

Any aspect ratio (default)

landscape → const NativeAdMediaAspectRatio

Landscape aspect ratio (16:9)

portrait → const NativeAdMediaAspectRatio

Portrait aspect ratio (9:16)

square → const NativeAdMediaAspectRatio

Square aspect ratio (1:1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NativeAdMediaAspectRatio>
A constant List of the values in this enum, in order of their declaration.