preloadedNativeAdId property
Optional preloaded native ad ID returned by loadNativeAd.
If provided, the widget will skip loading and render this preloaded ad.
Implementation
final String? preloadedNativeAdId;
Optional preloaded native ad ID returned by loadNativeAd.
If provided, the widget will skip loading and render this preloaded ad.
final String? preloadedNativeAdId;