setAdIdValidationPolicy method

void setAdIdValidationPolicy({
  1. bool? disallowTestIdsInRelease,
  2. bool? strict,
})

Configure validation policy for using Google's test ad unit IDs in release.

disallowTestIdsInRelease when true (default), will warn in release builds if a Google test ad unit ID is used. When false, the check is disabled.

strict when true, will throw an error in release builds if a Google test ad unit ID is used. When false (default), only warns.

Implementation

void setAdIdValidationPolicy({
  bool? disallowTestIdsInRelease,
  bool? strict,
}) {
  if (disallowTestIdsInRelease != null) {
    _disallowTestIdsInRelease = disallowTestIdsInRelease;
  }
  if (strict != null) {
    _strictTestIdPolicy = strict;
  }
}