AdTestIds class
Contains Google's test ad unit IDs for development.
Always use test ads during development to avoid policy violations. These IDs will show test ads that look like real ads but don't generate actual revenue.
Example:
final testInterstitial = Platform.isAndroid
? AdTestIds.androidInterstitial
: AdTestIds.iosInterstitial;
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- androidAppId → const String
- androidBanner → const String
- androidInterstitial → const String
- androidNativeAdvanced → const String
- androidRewarded → const String
- iosAppId → const String
- iosBanner → const String
- iosInterstitial → const String
- iosNativeAdvanced → const String
- iosRewarded → const String