NativeAdMediaStyle class
Media view configuration for native ads
Constructors
- NativeAdMediaStyle({double? aspectRatio, bool maintainAspectRatio = true, double? cornerRadius, Color? placeholderColor})
-
const
Properties
- aspectRatio → double?
-
Aspect ratio for media content (width/height)
Common values: 16/9 (1.77), 4/3 (1.33), 1/1 (1.0)
final
- cornerRadius → double?
-
Corner radius for media view
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maintainAspectRatio → bool
-
Whether to maintain aspect ratio
final
- placeholderColor → Color?
-
Background color while media is loading
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited